@@ -13,7 +13,7 @@ extern "C" {
 
 
 /** Defines the Baresip version string */
-#define BARESIP_VERSION "0.5.7"
+#define BARESIP_VERSION "0.5.8"
 
 
 #ifndef NET_MAX_NS
@@ -113,6 +113,7 @@ void call_set_handlers(struct call *call, call_event_h *eh,
 uint16_t      call_scode(const struct call *call);
 uint32_t      call_duration(const struct call *call);
 uint32_t      call_setup_duration(const struct call *call);
+const char   *call_id(const struct call *call);
 const char   *call_peeruri(const struct call *call);
 const char   *call_peername(const struct call *call);
 const char   *call_localuri(const struct call *call);
@@ -205,6 +206,8 @@ struct config_audio {
 	bool level;             /**< Enable audio level indication  */
 	int src_fmt;            /**< Audio source sample format     */
 	int play_fmt;           /**< Audio playback sample format   */
+	int enc_fmt;            /**< Audio encoder sample format    */
+	int dec_fmt;            /**< Audio decoder sample format    */
 };
 
 #ifdef USE_VIDEO
@@ -218,6 +221,7 @@ struct config_video {
 	uint32_t bitrate;       /**< Encoder bitrate in [bit/s]     */
 	uint32_t fps;           /**< Video framerate                */
 	bool fullscreen;        /**< Enable fullscreen display      */
+	int enc_fmt;            /**< Encoder pixelfmt (enum vidfmt) */
 };
 #endif
 
@@ -486,7 +490,7 @@ void log_register_handler(struct log *logh);
 void log_unregister_handler(struct log *logh);
 void log_enable_debug(bool enable);
 void log_enable_info(bool enable);
-void log_enable_stderr(bool enable);
+void log_enable_stdout(bool enable);
 void vlog(enum log_level level, const char *fmt, va_list ap);
 void loglv(enum log_level level, const char *fmt, ...);
 void debug(const char *fmt, ...);
@@ -826,6 +830,7 @@ const struct vidisp *vidisp_find(const struct list *vidispl, const char *name);
 /** Audio Codec parameters */
 struct auenc_param {
 	uint32_t ptime;  /**< Packet time in [ms]   */
+	uint32_t bitrate;/**< Wanted bitrate in [bit/s] */
 };
 
 struct auenc_state;
@@ -835,15 +840,17 @@ struct aucodec;
 typedef int (auenc_update_h)(struct auenc_state **aesp,
 			     const struct aucodec *ac,
 			     struct auenc_param *prm, const char *fmtp);
-typedef int (auenc_encode_h)(struct auenc_state *aes, uint8_t *buf,
-			     size_t *len, const int16_t *sampv, size_t sampc);
+typedef int (auenc_encode_h)(struct auenc_state *aes,
+			     uint8_t *buf, size_t *len,
+			     int fmt, const void *sampv, size_t sampc);
 
 typedef int (audec_update_h)(struct audec_state **adsp,
 			     const struct aucodec *ac, const char *fmtp);
-typedef int (audec_decode_h)(struct audec_state *ads, int16_t *sampv,
-			     size_t *sampc, const uint8_t *buf, size_t len);
+typedef int (audec_decode_h)(struct audec_state *ads,
+			     int fmt, void *sampv, size_t *sampc,
+			     const uint8_t *buf, size_t len);
 typedef int (audec_plc_h)(struct audec_state *ads,
-			  int16_t *sampv, size_t *sampc);
+			  int fmt, void *sampv, size_t *sampc);
 
 struct aucodec {
 	struct le le;
@@ -986,6 +993,7 @@ void audio_encoder_cycle(struct audio *audio);
 int  audio_level_get(const struct audio *au, double *level);
 int  audio_debug(struct re_printf *pf, const struct audio *a);
 struct stream *audio_strm(const struct audio *a);
+int audio_set_bitrate(struct audio *au, uint32_t bitrate);
 
 
 /*
