@@ -192,7 +192,9 @@ static int ffdecode(struct viddec_state *st, struct vidframe *frame)
 
 		ret = avcodec_send_packet(st->ctx, &avpkt);
 		if (ret < 0) {
-			warning("avcodec_send_packet error ret=%d\n", ret);
+			warning("avcodec: avcodec_send_packet error,"
+				" packet=%zu bytes, ret=%d (%s)\n",
+				st->mb->end, ret, av_err2str(ret));
 			err = EBADMSG;
 			goto out;
 		}
@@ -247,6 +249,10 @@ static int ffdecode(struct viddec_state *st, struct vidframe *frame)
 			frame->fmt = VID_FMT_NV12;
 			break;
 
+		case AV_PIX_FMT_YUV444P:
+			frame->fmt = VID_FMT_YUV444P;
+			break;
+
 		default:
 			warning("avcodec: decode: bad pixel format"
 				" (%i) (%s)\n",
@@ -333,6 +339,7 @@ int decode_h264(struct viddec_state *st, struct vidframe *frame,
 				      " ignoring NAL\n");
 				fragment_rewind(st);
 				++st->stats.n_lost;
+				return EPROTO;
 			}
 
 			st->frag_start = st->mb->pos;
@@ -351,7 +358,7 @@ int decode_h264(struct viddec_state *st, struct vidframe *frame,
 			if (!st->frag) {
 				debug("avcodec: ignoring fragment\n");
 				++st->stats.n_lost;
-				return 0;
+				return EPROTO;
 			}
 
 			if (seq_diff(st->frag_seq, seq) != 1) {
@@ -359,7 +366,7 @@ int decode_h264(struct viddec_state *st, struct vidframe *frame,
 				fragment_rewind(st);
 				st->frag = false;
 				++st->stats.n_lost;
-				return 0;
+				return EPROTO;
 			}
 		}
 
