@@ -35,7 +35,8 @@ enum {
 
 /** Media constants */
 enum {
-	AUDIO_BANDWIDTH = 128000 /**< Bandwidth for audio in bits/s       */
+	AUDIO_BANDWIDTH = 128000,  /**< Bandwidth for audio in bits/s      */
+	VIDEO_SRATE     =  90000,  /**< Sampling rate for video            */
 };
 
 
@@ -249,7 +250,7 @@ struct metric {
 void     metric_init(struct metric *metric);
 void     metric_reset(struct metric *metric);
 void     metric_add_packet(struct metric *metric, size_t packetsize);
-uint32_t metric_avg_bitrate(const struct metric *metric);
+double   metric_avg_bitrate(const struct metric *metric);
 
 
 /*
@@ -376,6 +377,7 @@ struct stream {
 	uint64_t ts_last;        /**< Timestamp of last received RTP pkt    */
 	bool terminated;         /**< Stream is terminated flag             */
 	uint32_t rtp_timeout_ms; /**< RTP Timeout value in [ms]             */
+	bool rtp_estab;          /**< True if RTP stream is established     */
 };
 
 int  stream_alloc(struct stream **sp, const struct stream_param *prm,
@@ -539,3 +541,10 @@ static inline int timestamp_wrap(uint32_t ts_new, uint32_t ts_old)
 
 	return 0;
 }
+
+
+/*
+ * Timer
+ */
+
+uint64_t tmr_jiffies_usec(void);
